@@ -128,7 +128,7 @@ class Session:
     def __enter__(self):
         return self
 
-    def __exit__(self):
+    def __exit__(self, *args):
         self.close()
 
     def close(self):
